==> waylandpp-1.0.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/waylandpp/waylandpp-targets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Waylandpp::wayland-client++" for configuration ""
set_property(TARGET Waylandpp::wayland-client++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-client++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-client++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-client++.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS Waylandpp::wayland-client++ )
list(APPEND _IMPORT_CHECK_FILES_FOR_Waylandpp::wayland-client++ "/usr/lib/libwayland-client++.so.1.0.0" )

# Import target "Waylandpp::wayland-client-extra++" for configuration ""
set_property(TARGET Waylandpp::wayland-client-extra++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-client-extra++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-client-extra++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-client-extra++.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS Waylandpp::wayland-client-extra++ )
list(APPEND _IMPORT_CHECK_FILES_FOR_Waylandpp::wayland-client-extra++ "/usr/lib/libwayland-client-extra++.so.1.0.0" )

# Import target "Waylandpp::wayland-egl++" for configuration ""
set_property(TARGET Waylandpp::wayland-egl++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-egl++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-egl++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-egl++.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS Waylandpp::wayland-egl++ )
list(APPEND _IMPORT_CHECK_FILES_FOR_Waylandpp::wayland-egl++ "/usr/lib/libwayland-egl++.so.1.0.0" )

# Import target "Waylandpp::wayland-cursor++" for configuration ""
set_property(TARGET Waylandpp::wayland-cursor++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-cursor++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-cursor++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-cursor++.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS Waylandpp::wayland-cursor++ )
list(APPEND _IMPORT_CHECK_FILES_FOR_Waylandpp::wayland-cursor++ "/usr/lib/libwayland-cursor++.so.1.0.0" )

# Import target "Waylandpp::wayland-client-unstable++" for configuration ""
set_property(TARGET Waylandpp::wayland-client-unstable++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-client-unstable++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-client-unstable++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-client-unstable++.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS Waylandpp::wayland-client-unstable++ )
list(APPEND _IMPORT_CHECK_FILES_FOR_Waylandpp::wayland-client-unstable++ "/usr/lib/libwayland-client-unstable++.so.1.0.0" )

# Import target "Waylandpp::wayland-server-unstable++" for configuration ""
set_property(TARGET Waylandpp::wayland-server-unstable++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-server-unstable++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-server-unstable++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-server-unstable++.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS Waylandpp::wayland-server-unstable++ )
list(APPEND _IMPORT_CHECK_FILES_FOR_Waylandpp::wayland-server-unstable++ "/usr/lib/libwayland-server-unstable++.so.1.0.0" )

# Import target "Waylandpp::wayland-server++" for configuration ""
set_property(TARGET Waylandpp::wayland-server++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-server++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-server++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-server++.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS Waylandpp::wayland-server++ )
list(APPEND _IMPORT_CHECK_FILES_FOR_Waylandpp::wayland-server++ "/usr/lib/libwayland-server++.so.1.0.0" )

# Import target "Waylandpp::wayland-server-extra++" for configuration ""
set_property(TARGET Waylandpp::wayland-server-extra++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-server-extra++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-server-extra++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-server-extra++.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS Waylandpp::wayland-server-extra++ )
list(APPEND _IMPORT_CHECK_FILES_FOR_Waylandpp::wayland-server-extra++ "/usr/lib/libwayland-server-extra++.so.1.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> waylandpp-1.0.0-2-aarch64.pkg.tar.xz: usr/lib/cmake/waylandpp/waylandpp-targets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Waylandpp::wayland-client++" for configuration ""
set_property(TARGET Waylandpp::wayland-client++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-client++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-client++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-client++.so.1"
  )

list(APPEND _cmake_import_check_targets Waylandpp::wayland-client++ )
list(APPEND _cmake_import_check_files_for_Waylandpp::wayland-client++ "/usr/lib/libwayland-client++.so.1.0.0" )

# Import target "Waylandpp::wayland-client-extra++" for configuration ""
set_property(TARGET Waylandpp::wayland-client-extra++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-client-extra++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-client-extra++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-client-extra++.so.1"
  )

list(APPEND _cmake_import_check_targets Waylandpp::wayland-client-extra++ )
list(APPEND _cmake_import_check_files_for_Waylandpp::wayland-client-extra++ "/usr/lib/libwayland-client-extra++.so.1.0.0" )

# Import target "Waylandpp::wayland-egl++" for configuration ""
set_property(TARGET Waylandpp::wayland-egl++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-egl++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-egl++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-egl++.so.1"
  )

list(APPEND _cmake_import_check_targets Waylandpp::wayland-egl++ )
list(APPEND _cmake_import_check_files_for_Waylandpp::wayland-egl++ "/usr/lib/libwayland-egl++.so.1.0.0" )

# Import target "Waylandpp::wayland-cursor++" for configuration ""
set_property(TARGET Waylandpp::wayland-cursor++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-cursor++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-cursor++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-cursor++.so.1"
  )

list(APPEND _cmake_import_check_targets Waylandpp::wayland-cursor++ )
list(APPEND _cmake_import_check_files_for_Waylandpp::wayland-cursor++ "/usr/lib/libwayland-cursor++.so.1.0.0" )

# Import target "Waylandpp::wayland-client-unstable++" for configuration ""
set_property(TARGET Waylandpp::wayland-client-unstable++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-client-unstable++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-client-unstable++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-client-unstable++.so.1"
  )

list(APPEND _cmake_import_check_targets Waylandpp::wayland-client-unstable++ )
list(APPEND _cmake_import_check_files_for_Waylandpp::wayland-client-unstable++ "/usr/lib/libwayland-client-unstable++.so.1.0.0" )

# Import target "Waylandpp::wayland-server-unstable++" for configuration ""
set_property(TARGET Waylandpp::wayland-server-unstable++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-server-unstable++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-server-unstable++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-server-unstable++.so.1"
  )

list(APPEND _cmake_import_check_targets Waylandpp::wayland-server-unstable++ )
list(APPEND _cmake_import_check_files_for_Waylandpp::wayland-server-unstable++ "/usr/lib/libwayland-server-unstable++.so.1.0.0" )

# Import target "Waylandpp::wayland-server++" for configuration ""
set_property(TARGET Waylandpp::wayland-server++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-server++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-server++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-server++.so.1"
  )

list(APPEND _cmake_import_check_targets Waylandpp::wayland-server++ )
list(APPEND _cmake_import_check_files_for_Waylandpp::wayland-server++ "/usr/lib/libwayland-server++.so.1.0.0" )

# Import target "Waylandpp::wayland-server-extra++" for configuration ""
set_property(TARGET Waylandpp::wayland-server-extra++ APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Waylandpp::wayland-server-extra++ PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libwayland-server-extra++.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libwayland-server-extra++.so.1"
  )

list(APPEND _cmake_import_check_targets Waylandpp::wayland-server-extra++ )
list(APPEND _cmake_import_check_files_for_Waylandpp::wayland-server-extra++ "/usr/lib/libwayland-server-extra++.so.1.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
